.. pyreadline3 documentation master file, created by sphinx-quickstart on Sat Jun 21 17:27:19 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyreadline3's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   installation
   usage
   bindable_commands
   known_issues
   changelog
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

